/****************************************************************************
** Meta object code from reading C++ file 'kkeysequencewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kxmlgui-6.28.0/src/kkeysequencewidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kkeysequencewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18KKeySequenceWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KKeySequenceWidget::qt_create_metaobjectdata<qt_meta_tag_ZN18KKeySequenceWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KKeySequenceWidget",
        "keySequenceChanged",
        "",
        "QKeySequence",
        "seq",
        "stealShortcut",
        "QAction*",
        "action",
        "recordingChanged",
        "captureKeySequence",
        "setKeySequence",
        "Validation",
        "val",
        "clearKeySequence",
        "applyStealShortcut",
        "keySequence",
        "multiKeyShortcutsAllowed",
        "checkForConflictsAgainst",
        "ShortcutTypes",
        "modifierlessAllowed",
        "modifierOnlyAllowed",
        "recording",
        "patterns",
        "KKeySequenceRecorder::Patterns",
        "ShortcutType",
        "None",
        "LocalShortcuts",
        "StandardShortcuts",
        "GlobalShortcuts"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keySequenceChanged'
        QtMocHelpers::SignalData<void(const QKeySequence &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'stealShortcut'
        QtMocHelpers::SignalData<void(const QKeySequence &, QAction *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'recordingChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'captureKeySequence'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setKeySequence'
        QtMocHelpers::SlotData<void(const QKeySequence &, enum Validation)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setKeySequence'
        QtMocHelpers::SlotData<void(const QKeySequence &)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'clearKeySequence'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applyStealShortcut'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'keySequence'
        QtMocHelpers::PropertyData<QKeySequence>(15, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'multiKeyShortcutsAllowed'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'checkForConflictsAgainst'
        QtMocHelpers::PropertyData<ShortcutTypes>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'modifierlessAllowed'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'modifierOnlyAllowed'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'recording'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'patterns'
        QtMocHelpers::PropertyData<KKeySequenceRecorder::Patterns>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'ShortcutTypes'
        QtMocHelpers::EnumData<ShortcutTypes>(18, 24, QMC::EnumIsFlag).add({
            {   25, ShortcutType::None },
            {   26, ShortcutType::LocalShortcuts },
            {   27, ShortcutType::StandardShortcuts },
            {   28, ShortcutType::GlobalShortcuts },
        }),
    };
    return QtMocHelpers::metaObjectData<KKeySequenceWidget, qt_meta_tag_ZN18KKeySequenceWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN18KKeySequenceWidgetE[] = {
    QMetaObject::SuperData::link<KKeySequenceRecorder::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KKeySequenceWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KKeySequenceWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KKeySequenceWidgetE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN18KKeySequenceWidgetE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18KKeySequenceWidgetE_t>.metaTypes,
    nullptr
} };

void KKeySequenceWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KKeySequenceWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keySequenceChanged((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 1: _t->stealShortcut((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[2]))); break;
        case 2: _t->recordingChanged(); break;
        case 3: _t->captureKeySequence(); break;
        case 4: _t->setKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Validation>>(_a[2]))); break;
        case 5: _t->setKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 6: _t->clearKeySequence(); break;
        case 7: _t->applyStealShortcut(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceWidget::*)(const QKeySequence & )>(_a, &KKeySequenceWidget::keySequenceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceWidget::*)(const QKeySequence & , QAction * )>(_a, &KKeySequenceWidget::stealShortcut, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceWidget::*)()>(_a, &KKeySequenceWidget::recordingChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QKeySequence*>(_v) = _t->keySequence(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->multiKeyShortcutsAllowed(); break;
        case 2: QtMocHelpers::assignFlags<ShortcutTypes>(_v, _t->checkForConflictsAgainst()); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isModifierlessAllowed(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->modifierOnlyAllowed(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isRecording(); break;
        case 6: *reinterpret_cast<KKeySequenceRecorder::Patterns*>(_v) = _t->patterns(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setKeySequence(*reinterpret_cast<QKeySequence*>(_v)); break;
        case 1: _t->setMultiKeyShortcutsAllowed(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setCheckForConflictsAgainst(*reinterpret_cast<ShortcutTypes*>(_v)); break;
        case 3: _t->setModifierlessAllowed(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setModifierOnlyAllowed(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setPatterns(*reinterpret_cast<KKeySequenceRecorder::Patterns*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KKeySequenceWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KKeySequenceWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KKeySequenceWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KKeySequenceWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KKeySequenceWidget::keySequenceChanged(const QKeySequence & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KKeySequenceWidget::stealShortcut(const QKeySequence & _t1, QAction * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KKeySequenceWidget::recordingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
